@@ -37,22 +37,7 @@ from zwave_js_server.model.node import Node
 from zwave_js_server.model.node.firmware import NodeFirmwareUpdateInfo
 
 from .. import load_fixture
-
-FIRMWARE_UPDATE_INFO = {
-    "version": "1.0.0",
-    "changelog": "changelog",
-    "channel": "stable",
-    "files": [{"target": 0, "url": "http://example.com", "integrity": "test"}],
-    "downgrade": True,
-    "normalizedVersion": "1.0.0",
-    "device": {
-        "manufacturerId": 1,
-        "productType": 2,
-        "productId": 3,
-        "firmwareVersion": "0.4.4",
-        "rfRegion": 1,
-    },
-}
+from .common import FIRMWARE_UPDATE_INFO
 
 
 def test_from_state():
@@ -1617,6 +1602,7 @@ async def test_statistics_updated(controller):
     assert event_stats.background_rssi.channel_1.average == -93
     assert event_stats.background_rssi.channel_1.current == -94
     assert event_stats.background_rssi.channel_2 is None
+    assert event_stats.background_rssi.channel_3 is None
 
     statistics_data = {
         "messagesTX": 1,
@@ -1663,6 +1649,52 @@ async def test_statistics_updated(controller):
     assert event_stats.background_rssi.channel_1.current == -84
     assert event_stats.background_rssi.channel_2.average == -85
     assert event_stats.background_rssi.channel_2.current == -86
+    assert event_stats.background_rssi.channel_3 is None
+
+    statistics_data = {
+        "messagesTX": 1,
+        "messagesRX": 1,
+        "messagesDroppedRX": 1,
+        "NAK": 1,
+        "CAN": 1,
+        "timeoutACK": 1,
+        "timeoutResponse": 1,
+        "timeoutCallback": 1,
+        "messagesDroppedTX": 1,
+        "backgroundRSSI": {
+            "timestamp": 1234567890,
+            "channel0": {
+                "average": -81,
+                "current": -82,
+            },
+            "channel1": {
+                "average": -83,
+                "current": -84,
+            },
+            "channel2": {
+                "average": -85,
+                "current": -86,
+            },
+            "channel3": {
+                "average": -87,
+                "current": -88,
+            },
+        },
+    }
+    event = Event(
+        "statistics updated",
+        {
+            "source": "controller",
+            "event": "statistics updated",
+            "statistics": statistics_data,
+        },
+    )
+    controller.receive_event(event)
+    event_stats = event.data["statistics_updated"]
+    assert isinstance(event_stats, ControllerStatistics)
+    assert event_stats.background_rssi
+    assert event_stats.background_rssi.channel_3.average == -87
+    assert event_stats.background_rssi.channel_3.current == -88
 
 
 async def test_grant_security_classes(controller, uuid4, mock_command) -> None:
@@ -1769,13 +1801,24 @@ async def test_restore_nvm(controller, uuid4, mock_command):
         {"command": "controller.restore_nvm"},
         {},
     )
-    await controller.async_restore_nvm(bytes(10))
+    await controller.async_restore_nvm(bytes(10), {})
 
     assert len(ack_commands) == 1
     assert ack_commands[0] == {
         "command": "controller.restore_nvm",
         "nvmData": "AAAAAAAAAAAAAA==",
         "messageId": uuid4,
+        "migrateOptions": {},
+    }
+
+    await controller.async_restore_nvm(bytes(10), {"preserveRoutes": False})
+
+    assert len(ack_commands) == 2
+    assert ack_commands[1] == {
+        "command": "controller.restore_nvm",
+        "nvmData": "AAAAAAAAAAAAAA==",
+        "messageId": uuid4,
+        "migrateOptions": {"preserveRoutes": False},
     }
 
 
@@ -1807,6 +1850,7 @@ async def test_restore_nvm_base64(controller, uuid4, mock_command):
         "command": "controller.restore_nvm",
         "nvmData": "AAAAAAAAAAAAAA==",
         "messageId": uuid4,
+        "migrateOptions": {},
     }
 
 
@@ -2199,7 +2243,7 @@ async def test_node_added(controller, multisensor_6_state):
             "source": "controller",
             "event": "node added",
             "node": multisensor_6_state,
-            "result": "",
+            "result": {},
         },
     )
     controller.receive_event(event)
