@@ -1,4 +1,5 @@
 """Data model for a Z-Wave JS controller."""
+
 from __future__ import annotations
 
 from typing import TypedDict
@@ -16,7 +17,7 @@ class ControllerDataType(TypedDict, total=False):
     isPrimary: bool
     isSUC: bool
     nodeType: int
-    isUsingHomeIdFromOtherNetwork: bool  # TODO: The following items are missing in the docs.
+    isUsingHomeIdFromOtherNetwork: bool
     isSISPresent: bool
     wasRealPrimary: bool
     firmwareVersion: str
@@ -26,8 +27,10 @@ class ControllerDataType(TypedDict, total=False):
     supportedFunctionTypes: list[int]
     sucNodeId: int
     supportsTimers: bool
-    isHealNetworkActive: bool
+    isRebuildingRoutes: bool
     statistics: ControllerStatisticsDataType
     inclusionState: int
     rfRegion: int
     status: int
+    rebuildRoutesProgress: dict[str, str]
+    supportsLongRange: bool
