@@ -2,52 +2,56 @@
 
 from __future__ import annotations
 
-from dataclasses import asdict, dataclass, field
+from dataclasses import dataclass, field
 from enum import IntEnum
-from typing import TYPE_CHECKING, Literal, TypedDict, cast
+from typing import TYPE_CHECKING, Required, TypedDict, cast
 
-from ...const import VALUE_UNKNOWN, RFRegion
-from ...util.helpers import convert_bytes_to_base64
+from zwave_js_server.model.firmware import (
+    FirmwareUpdateData,
+    FirmwareUpdateDataDataType,
+    FirmwareUpdateDeviceID,
+    FirmwareUpdateDeviceIDDataType,
+    FirmwareUpdateFileInfo,
+    FirmwareUpdateFileInfoDataType,
+    FirmwareUpdateInfo,
+    FirmwareUpdateInfoDataType,
+    FirmwareUpdateProgress,
+    FirmwareUpdateProgressDataType,
+    FirmwareUpdateResult,
+    FirmwareUpdateResultDataType,
+)
+
+from ...const import VALUE_UNKNOWN
 
 if TYPE_CHECKING:
     from . import Node
 
 
-class NodeFirmwareUpdateDataDataType(TypedDict, total=False):
+class NodeFirmwareUpdateDataDataType(FirmwareUpdateDataDataType):
     """Represent a firmware update data dict type."""
 
-    filename: str  # required
-    file: str  # required
-    fileFormat: str
     firmwareTarget: int
 
 
 @dataclass
-class NodeFirmwareUpdateData:
+class NodeFirmwareUpdateData(FirmwareUpdateData):
     """Firmware update data."""
 
-    filename: str
-    file: bytes
-    file_format: str | None = None
     firmware_target: int | None = None
 
     def to_dict(self) -> NodeFirmwareUpdateDataDataType:
         """Convert firmware update data to dict."""
-        data: NodeFirmwareUpdateDataDataType = {
-            "filename": self.filename,
-            "file": convert_bytes_to_base64(self.file),
-        }
-        if self.file_format is not None:
-            data["fileFormat"] = self.file_format
+        data = super().to_dict()
+        node_data = cast(NodeFirmwareUpdateDataDataType, data)
         if self.firmware_target is not None:
-            data["firmwareTarget"] = self.firmware_target
-        return data
+            node_data["firmwareTarget"] = self.firmware_target
+        return node_data
 
 
 class NodeFirmwareUpdateCapabilitiesDataType(TypedDict, total=False):
     """Represent a firmware update capabilities dict type."""
 
-    firmwareUpgradable: bool  # required
+    firmwareUpgradable: Required[bool]
     firmwareTargets: list[int]
     continuesToFunction: bool | str
     supportsActivation: bool | str
@@ -56,7 +60,7 @@ class NodeFirmwareUpdateCapabilitiesDataType(TypedDict, total=False):
 class NodeFirmwareUpdateCapabilitiesDict(TypedDict, total=False):
     """Represent a dict from FirmwareUpdateCapabilities."""
 
-    firmware_upgradable: bool  # required
+    firmware_upgradable: Required[bool]
     firmware_targets: list[int]
     continues_to_function: bool | None
     supports_activation: bool | None
@@ -133,193 +137,125 @@ class NodeFirmwareUpdateStatus(IntEnum):
     OK_RESTART_PENDING = 255
 
 
-class NodeFirmwareUpdateProgressDataType(TypedDict):
+class NodeFirmwareUpdateProgressDataType(FirmwareUpdateProgressDataType):
     """Represent a node firmware update progress dict type."""
 
     currentFile: int
     totalFiles: int
-    sentFragments: int
-    totalFragments: int
-    progress: float
 
 
 @dataclass
-class NodeFirmwareUpdateProgress:
+class NodeFirmwareUpdateProgress(FirmwareUpdateProgress):
     """Model for a node firmware update progress data."""
 
     node: Node
     data: NodeFirmwareUpdateProgressDataType = field(repr=False)
     current_file: int = field(init=False)
     total_files: int = field(init=False)
-    sent_fragments: int = field(init=False)
-    total_fragments: int = field(init=False)
-    progress: float = field(init=False)
+
+    def __init__(self, node: Node, data: NodeFirmwareUpdateProgressDataType) -> None:
+        """Initialize the node firmware update progress.
+
+        Explicit init method to retain backwards compatibility
+        that requires the node as first parameter.
+        """
+        super().__init__(data)
+        self.node = node
 
     def __post_init__(self) -> None:
         """Post initialize."""
+        super().__post_init__()
         self.current_file = self.data["currentFile"]
         self.total_files = self.data["totalFiles"]
-        self.sent_fragments = self.data["sentFragments"]
-        self.total_fragments = self.data["totalFragments"]
-        self.progress = float(self.data["progress"])
 
 
-class NodeFirmwareUpdateResultDataType(TypedDict, total=False):
+class NodeFirmwareUpdateResultDataType(FirmwareUpdateResultDataType, total=False):
     """Represent a node firmware update result dict type."""
 
-    status: int  # required
-    success: bool  # required
     waitTime: int
-    reInterview: bool  # required
+    reInterview: Required[bool]
 
 
 @dataclass
-class NodeFirmwareUpdateResult:
+class NodeFirmwareUpdateResult(FirmwareUpdateResult):
     """Model for node firmware update result data."""
 
     node: Node
     data: NodeFirmwareUpdateResultDataType = field(repr=False)
     status: NodeFirmwareUpdateStatus = field(init=False)
-    success: bool = field(init=False)
     wait_time: int | None = field(init=False)
     reinterview: bool = field(init=False)
+    _status_class = NodeFirmwareUpdateStatus
+
+    def __init__(self, node: Node, data: NodeFirmwareUpdateResultDataType) -> None:
+        """Initialize the node firmware update result.
+
+        Explicit init method to retain backwards compatibility
+        that requires the node as first parameter.
+        """
+        super().__init__(data)
+        self.node = node
 
     def __post_init__(self) -> None:
         """Post initialize."""
-        self.status = NodeFirmwareUpdateStatus(self.data["status"])
-        self.success = self.data["success"]
+        super().__post_init__()
         self.wait_time = self.data.get("waitTime")
         self.reinterview = self.data["reInterview"]
 
 
-class NodeFirmwareUpdateFileInfoDataType(TypedDict):
-    """Represent a firmware update file info data dict type."""
-
-    target: int
-    url: str
-    integrity: str  # sha256
+class NodeFirmwareUpdateFileInfoDataType(FirmwareUpdateFileInfoDataType):
+    """Represent a node firmware update file info data dict type."""
 
 
 @dataclass
-class NodeFirmwareUpdateFileInfo:
+class NodeFirmwareUpdateFileInfo(FirmwareUpdateFileInfo):
     """Represent a firmware update file info."""
 
-    target: int
-    url: str
-    integrity: str
-
     @classmethod
     def from_dict(
         cls, data: NodeFirmwareUpdateFileInfoDataType
     ) -> NodeFirmwareUpdateFileInfo:
         """Initialize from dict."""
-        return cls(
-            target=data["target"],
-            url=data["url"],
-            integrity=data["integrity"],
-        )
+        return cast(NodeFirmwareUpdateFileInfo, super().from_dict(data))
 
     def to_dict(self) -> NodeFirmwareUpdateFileInfoDataType:
         """Return dict representation of the object."""
-        return cast(NodeFirmwareUpdateFileInfoDataType, asdict(self))
+        return super().to_dict()
 
 
-class NodeFirmwareUpdateDeviceIDDataType(TypedDict, total=False):
-    """Represent a firmware update device ID dict type."""
-
-    manufacturerId: int  # required
-    productType: int  # required
-    productId: int  # required
-    firmwareVersion: str  # required
-    rfRegion: int
+class NodeFirmwareUpdateDeviceIDDataType(FirmwareUpdateDeviceIDDataType):
+    """Represent a node firmware update device ID data dict type."""
 
 
 @dataclass
-class NodeFirmwareUpdateDeviceID:
+class NodeFirmwareUpdateDeviceID(FirmwareUpdateDeviceID):
     """Represent a firmware update device ID."""
 
-    manufacturer_id: int
-    product_type: int
-    product_id: int
-    firmware_version: str
-    rf_region: RFRegion | None
-
     @classmethod
     def from_dict(
         cls, data: NodeFirmwareUpdateDeviceIDDataType
     ) -> NodeFirmwareUpdateDeviceID:
         """Initialize from dict."""
-        return cls(
-            manufacturer_id=data["manufacturerId"],
-            product_type=data["productType"],
-            product_id=data["productId"],
-            firmware_version=data["firmwareVersion"],
-            rf_region=RFRegion(data["rfRegion"]) if "rfRegion" in data else None,
-        )
+        return cast(NodeFirmwareUpdateDeviceID, super().from_dict(data))
 
     def to_dict(self) -> NodeFirmwareUpdateDeviceIDDataType:
         """Return dict representation of the object."""
-        data = {
-            "manufacturerId": self.manufacturer_id,
-            "productType": self.product_type,
-            "productId": self.product_id,
-            "firmwareVersion": self.firmware_version,
-        }
-        if self.rf_region is not None:
-            data["rfRegion"] = self.rf_region
-        return cast(NodeFirmwareUpdateDeviceIDDataType, data)
+        return super().to_dict()
 
 
-class NodeFirmwareUpdateInfoDataType(TypedDict, total=False):
-    """Represent a firmware update info data dict type."""
-
-    version: str
-    changelog: str
-    channel: Literal["stable", "beta"]
-    files: list[NodeFirmwareUpdateFileInfoDataType]
-    downgrade: bool
-    normalizedVersion: str
-    device: NodeFirmwareUpdateDeviceIDDataType
+class NodeFirmwareUpdateInfoDataType(FirmwareUpdateInfoDataType):
+    """Represent a node firmware update info data dict type."""
 
 
 @dataclass
-class NodeFirmwareUpdateInfo:
+class NodeFirmwareUpdateInfo(FirmwareUpdateInfo):
     """Represent a firmware update info."""
 
-    version: str
-    changelog: str
-    channel: Literal["stable", "beta"]
-    files: list[NodeFirmwareUpdateFileInfo]
-    downgrade: bool
-    normalized_version: str
-    device: NodeFirmwareUpdateDeviceID
-
     @classmethod
     def from_dict(cls, data: NodeFirmwareUpdateInfoDataType) -> NodeFirmwareUpdateInfo:
         """Initialize from dict."""
-        return cls(
-            version=data["version"],
-            changelog=data["changelog"],
-            channel=data["channel"],
-            files=[
-                NodeFirmwareUpdateFileInfo.from_dict(file) for file in data["files"]
-            ],
-            downgrade=data["downgrade"],
-            normalized_version=data["normalizedVersion"],
-            device=NodeFirmwareUpdateDeviceID.from_dict(data["device"]),
-        )
+        return cast(NodeFirmwareUpdateInfo, super().from_dict(data))
 
     def to_dict(self) -> NodeFirmwareUpdateInfoDataType:
         """Return dict representation of the object."""
-        return cast(
-            NodeFirmwareUpdateInfoDataType,
-            {
-                "version": self.version,
-                "changelog": self.changelog,
-                "channel": self.channel,
-                "files": [file.to_dict() for file in self.files],
-                "downgrade": self.downgrade,
-                "normalizedVersion": self.normalized_version,
-                "device": self.device.to_dict(),
-            },
-        )
+        return super().to_dict()
